@@ -1,7 +1,7 @@
 /* boot.c  -  Boot image composition */
 /*
 Copyright 1992-1997 Werner Almesberger.
-Copyright 1999-2003 John Coffman.
+Copyright 1999-2004 John Coffman.
 All rights reserved.
 
 Licensed under the terms contained in the file 'COPYING' in the 
@@ -10,6 +10,7 @@ source directory.
 */
 #define BIG_CHAIN 5
 
+#define _GNU_SOURCE
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -100,7 +101,7 @@ void boot_image(char *spec,IMAGE_DESCR *descr)
 	fd = geo_open(&geo,initrd,O_RDONLY);
 	if (fstat(fd,&st) < 0) die("fstat %s: %s",initrd,strerror(errno));
 #if 1
-	*(unsigned long *) descr->rd_size = st.st_size;
+	*(unsigned int *) descr->rd_size = st.st_size;
 #else
 	descr->rd_size = (st.st_size + SECTOR_SIZE - 1)/SECTOR_SIZE;
 #endif
@@ -322,11 +323,14 @@ void boot_other(char *loader,char *boot,char *part,IMAGE_DESCR *descr)
 
     if (!loader) loader = DFL_CHAIN;
 #ifdef LCF_BUILTIN
+#ifndef LCF_SOLO_CHAIN
     if (strstr(loader,"os2")) {
 	chain = &Os2_d;
 	cname = "OS/2";
     }
-    else {
+    else
+#endif
+    {
 	chain = &Chain;
 	cname = "CHAIN";
     }
@@ -379,7 +383,19 @@ void boot_other(char *loader,char *boot,char *part,IMAGE_DESCR *descr)
 	if (fstat(b_fd,&st) < 0)
 	    die("fstat %s: %s",boot,strerror(errno));
 	if (!geo.file) part_verify(st.st_rdev,0);
-	if (lseek(b_fd,(long) BOOT_SIG_OFFSET,SEEK_SET) < 0)
+	else if (st.st_size > SECTOR_SIZE && !nowarn) {
+	    fprintf(errstd,"Warning: 'other = %s' specifies a file that is longer\n"
+	    	"    than a single sector.", boot);
+	    if (st.st_size >= SECTOR_SIZE*(SETUPSECS-1) &&
+	        read(b_fd, buff[0].sector, SECTOR_SIZE*(SETUPSECS-1)) == 
+	    		SECTOR_SIZE*(SETUPSECS-1)   &&
+	    	!strncmp(buff[2].sector+2,"HdrS",4)
+	    			) {
+		fprintf(errstd,"  This file may actually be an 'image ='");
+	    }
+	    fprintf(errstd, "\n");
+	}
+	if (lseek(b_fd,(int) BOOT_SIG_OFFSET,SEEK_SET) < 0)
 	    die("lseek %s: %s",boot,strerror(errno));
 	if ((size = read(b_fd, (char *)&magic, 2)) != 2) {
 	    if (size < 0) die("read %s: %s",boot,strerror(errno));
@@ -453,7 +469,7 @@ void boot_other(char *loader,char *boot,char *part,IMAGE_DESCR *descr)
     else {
 	if ((p_fd = open(part,O_RDONLY)) < 0)
 	    die("open %s: %s",part,strerror(errno));
-	if (lseek(p_fd,(long) PART_TABLE_OFFSET,SEEK_SET) < 0)
+	if (lseek(p_fd,(int) PART_TABLE_OFFSET,SEEK_SET) < 0)
 	    die("lseek %s: %s",part,strerror(errno));
 	if (read(p_fd,(char *) buff[0].par_c.ptable,PART_TABLE_SIZE) !=
 	  PART_TABLE_SIZE)
