@@ -1,7 +1,7 @@
 /* common.c  -  Common data structures and functions. */
 /*
 Copyright 1992-1998 Werner Almesberger.
-Copyright 1999-2002 John Coffman.
+Copyright 1999-2004 John Coffman.
 All rights reserved.
 
 Licensed under the terms contained in the file 'COPYING' in the 
@@ -10,6 +10,7 @@ source directory.
 */
 
 
+#define _GNU_SOURCE
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -32,7 +33,7 @@ FILE *pp_fd = NULL;
 int bios_boot, bios_map;
 unsigned short drv_map[DRVMAP_SIZE+1]; /* fixup maps ... */
 int curr_drv_map;
-unsigned long prt_map[PRTMAP_SIZE+1];
+unsigned int prt_map[PRTMAP_SIZE+1];
 int curr_prt_map;
 
 
@@ -98,6 +99,35 @@ int to_number(char *num)
 }
 
 
+int timer_number(char *num)
+{
+    int number;
+    char *end;
+
+    number = strtol(num,&end,0);
+    if (end && *end) {
+	switch (*end) {
+	    case 'h':
+	    case 'H':
+		number *= 60;
+	    case 'm':
+	    case 'M':
+		number *= 60;
+	    case 's':
+	    case 'S':
+		number *= 10;		/* convert seconds to tenths */
+	    case 't':
+	    case 'T':
+		break;
+	    default:
+		number = -1;
+	}
+    }
+    if (number < 0  ||  number > 36000)  die("Not a valid timer value: \"%s\"",num);
+    return number;
+}
+
+
 static char *name(int stage)
 {
     switch (stage) {
@@ -143,10 +173,10 @@ int stat_equal(struct stat *a,struct stat *b)
 
 /* accumulate a partial CRC-32 */
 
-unsigned long crc32partial(unsigned char *cp, int nsize,
-			unsigned long polynomial, unsigned long *accum)
+unsigned int crc32partial(unsigned char *cp, int nsize,
+			unsigned int polynomial, unsigned int *accum)
 {
-   unsigned long poly, crc;
+   unsigned int poly, crc;
    int i;
    unsigned char ch;
 
@@ -165,9 +195,9 @@ unsigned long crc32partial(unsigned char *cp, int nsize,
 
 /* calculate a CRC-32 polynomial */
 
-unsigned long crc32 (unsigned char *cp, int nsize, unsigned long polynomial)
+unsigned int crc32 (unsigned char *cp, int nsize, unsigned int polynomial)
 {
-    unsigned long crc = 0;
+    unsigned int crc = 0;
     return crc32partial(cp, nsize, polynomial, &crc);
 }
 
@@ -197,7 +227,7 @@ int main(int argc, char *argv[])
 {
     unsigned char buf[4096];
     int fd, n;
-    unsigned long crc;
+    unsigned int crc;
     
     fd = open(argv[1],O_RDONLY);
     crc = 0;
@@ -209,6 +239,17 @@ int main(int argc, char *argv[])
     close(fd);
 
     printf("0x%08x\n", (int)crc);
+    if (sizeof(short)!=2) {
+	fprintf(stderr,"***Fatal:  SHORT != 2\n");
+	return 1;
+    }
+    if (sizeof(int)!=4) {
+	fprintf(stderr, "*****Fatal:  INT != 4\n");
+	return 1;
+    }
+    if (sizeof(long)>sizeof(int))
+	fprintf(stderr, "**Note:  LONG is bigger than INT\n");
+	
     return 0;
 }
 #endif	/* SHS_MAIN */
