@@ -13,6 +13,11 @@ source directory.
 #ifndef CONFIG_H
 #define CONFIG_H
 
+#if !defined(__GLIBC__) || (__GLIBC__ < 2) || \
+	 !defined(__GLIBC_MINOR__) || (__GLIBC_MINOR__ < 1)
+# warning "glibc version 2.1 or later is recommended"
+#endif
+
 #define TMP_DEV     "/tmp/dev.%d" /* temporary devices are created here */
 #define MAX_TMP_DEV 50 /* highest temp. device number */
 
