@@ -222,6 +222,11 @@ int dev_open(DEVICE *dev,int number,int flags)
 	}
 	else cache_add(name,number);
     }
+#if BETA_TEST
+	if (verbose >= 3) printf("stat-ing %s\n", name);
+	fflush(stdout);
+	stat(name, &st.st);
+#endif
     if (flags == O_BYPASS) dev->fd = -1;
     else if ((dev->fd = open(name,flags)) < 0)
 	    die("open %s: %s",name,strerror(errno));
@@ -1020,7 +1025,11 @@ static int warned = 0, called = 0;
 
 		    dev_close(&Dev2);
 
+#if 0
 		    geo_query_dev(&geo, dev, 1);
+#else
+		    geo_query_dev(&geo, dev, MAJOR(dev)!=MAJOR_LOOP);
+#endif
 		    vm[ndevs].bios.probe = bios_device(&geo, dev);
 
 		    if (serial_valid(serial, DEV_MASK)) {
@@ -1233,7 +1242,7 @@ static int warned = 0, called = 0;
 		    else if (vm[i].bios.user == bios+0x80) k = i;
 		}
 #if BETA_TEST
-		printf("J=%d  K=%d\n", j, k);
+		if (verbose>=3) printf("J=%d  K=%d\n", j, k);
 #endif
 		if (j<0 && k>=0) {
 		    die("Devices %04X and %04X are assigned to BIOS 0x%02X",
