@@ -668,6 +668,7 @@ void geo_query_dev(GEOMETRY *geo,int device,int all)
 	    break;
 
 	default:
+	    if (max_partno[major] && major==MAJOR_LOOP) break;
 	    if (max_partno[major] == 63)  goto MASK63;
 	    if (max_partno[major] == 15)  goto MASK15;
 	    if (max_partno[major] == 7)   goto MASK7;
@@ -1079,6 +1080,12 @@ int geo_comp_addr(GEOMETRY *geo,int offset,SECTOR_ADDR *addr)
     int block,sector;
     static int warnings = 0;
 
+#if BETA_TEST
+    if (verbose>=6)
+	printf("geo_comp_addr: dev = %x, offset=%d\n",
+		geo->device, offset);
+#endif
+
 #if 0
     if (linear && lba32)
        die("'linear' and 'lba32' (-l and -L) are mutually exclusive.");
@@ -1190,10 +1197,16 @@ int geo_comp_addr(GEOMETRY *geo,int offset,SECTOR_ADDR *addr)
     }
     else {
 	addr->device = geo->device;
-	addr->sector = (sector % geo->sectors)+1;
-	sector /= geo->sectors;
-	addr->head = sector % geo->heads;
-	sector /= geo->heads;
+	addr->sector = 1;
+	addr->head = 0;
+	if (sector) {
+	    if (geo->heads == 0)
+		die("BIOS device 0x%02x is inaccessible", geo->device);
+	    addr->sector = (sector % geo->sectors)+1;
+ 	    sector /= geo->sectors;
+	    addr->head = sector % geo->heads;
+	    sector /= geo->heads;
+	}
 	if (sector >= BIOS_MAX_CYLS)
 	    die("geo_comp_addr: Cylinder number is too big (%d > %d)",sector,
 	      BIOS_MAX_CYLS-1);
