@@ -87,6 +87,7 @@ source directory.
 #define MAJOR_FD	2 /* floppy disks */
 #define MAJOR_HPT370_SORT  MAJOR_FD	/* 114->2 for sorting HPT370 controller */
 #define MAJOR_HD	3 /* IDE-type hard disks */
+#define MAJOR_LOOP	7 /* Loopback devices 0-15 */
 #define MAJOR_SD	8 /* SCSI disks 0-15 */
 #define MAJOR_MD	9 /* multi-disk RAID sets */
 #define MAJOR_XT	13 /* XT-type hard disks */
@@ -162,6 +163,7 @@ source directory.
 #define MAX_IMAGES      ((int)((SECTOR_SIZE*MAX_DESCR_SECS-sizeof(int)-1)/sizeof(IMAGE_DESCR)))
 			  /* maximum number of images */
 
+#define COMMAND_LINE_SIZE	256	/* CL_LENGTH */
 #define SECTOR_SIZE	512 /* disk sector size */
 #ifndef BLOCK_SIZE /* may also come from linux/fs.h */
 #define BLOCK_SIZE	1024 /* disk block size */
@@ -430,7 +432,7 @@ KBHIGH	  = 0x3e
 CL_MAGIC_ADDR	= 0x20			! command line magic number
 CL_MAGIC	= 0xa33f		! very unusual command sequence
 CL_OFFSET	= 0x22			! command line offset
-CL_LENGTH	= 256			! maximum length
+CL_LENGTH	= COMMAND_LINE_SIZE	! maximum length = 256-1
 
 ! 0x90020-0x90021     2 by   command line magic number
 ! 0x90022-0x90023     2 by   command line offset
@@ -444,6 +446,18 @@ CL_RAMDISK_MAX	= CL_POINTER+4		! ramdisk_max; header version 0x0203
 
 #endif
 
+/* Bug fix needed for some S-ATA controllers with the Silicon Image
+   3112 or 3114 chipsets.  Early versions of the SI BIOS do not properly
+   update the low memory size in the BIOS Data Area at 40h:13h when
+   they allocate space in the Extended BIOS Data Area (EBDA).
+*/
+#ifdef LCF_BUG_SI_EBDA
+# define EBDA_EXTRA LCF_BUG_SI_EBDA
+#else
+# define EBDA_EXTRA 0
+#endif
+
+
 /* the following configuration variable are now  required
    don't compile without them ...
  */
