@@ -692,7 +692,7 @@ void do_install_mbr(char *part, char *what)
     extended_pt |= !!strchr(what,'x') || !!strchr(what,'X') || !!strchr(what,'2');
     if ((fd=open(part,O_RDWR)) < 0) die("Cannot open %s: %s", part,strerror(errno));
     if (fstat(fd,&st) < 0) die("stat: %s : %s", part,strerror(errno));
-    if (!S_ISBLK(st.st_mode)) die("%s not a block device",part);
+    if (!S_ISBLK(st.st_mode) && !force_fs) die("%s not a block device",part);
     if (st.st_rdev != (st.st_rdev & has_partitions(st.st_rdev)))
 	die("%s is not a master device with a primary parition table",part);
     if (read(fd,&buf,SECTOR_SIZE) != SECTOR_SIZE) die("read %s: %s",part, strerror(errno));
