@@ -22,7 +22,6 @@ source directory.
 #include <errno.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <linux/unistd.h>
 #include "lilo.h"
 #include "common.h"
 #include "device.h"
@@ -31,7 +30,7 @@ source directory.
 #include "bsect.h"
 #include "bdata.h"
 #include "probe.h"
-/*#include "lrmi.h"*/
+
 
 #ifdef LCF_BDATA
 #if BD_MAX_FLOPPY > 4
@@ -497,7 +496,11 @@ static void do_ebda(void)
     int m, n, init;
     static char EBDA[]="Extended BIOS Data Area (EBDA)";
     
-    m = get_conv_mem();
+    m = get_conv_mem() - EBDA_EXTRA;
+#if EBDA_EXTRA
+    printf("*** BUGFIX - reported EBDA is increased by %dK - BUGFIX ***\n",
+    	EBDA_EXTRA);
+#endif
     if (m==640) printf("    no %s\n", EBDA);
     else printf("    %s = %dK\n", EBDA, 640-m);
     printf("    Conventional Memory = %dK    0x%06X\n", m, m<<10);
@@ -1103,7 +1106,7 @@ static char *ord[] =
 	char *cp = NULL;
 	char *cn = NULL;
 
-	if (code==0) { cp="floppy"; cn=ord[0]; }
+	if (code>=0 && code<2) { cp="floppy"; cn=ord[code]; }
 	if (code>=0x80 && code<=0x8f) { cp="hard"; cn=ord[code&15]; }
 	if (cp)
 	printf("  If you\nactually booted from the %s %s drive, then this assumption is okay.",
