@@ -1,6 +1,6 @@
 /* raid.c  -  The RAID-1 hooks for LILO */
 /*
-Copyright 2001-2003 John Coffman.
+Copyright 2001-2004 John Coffman.
 All rights reserved.
 
 Licensed under the terms contained in the file 'COPYING' in the 
@@ -8,6 +8,7 @@ source directory.
 
 */
 
+#define _GNU_SOURCE
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -34,7 +35,7 @@ source directory.
 static int lowest;
 static DT_ENTRY *md_disk;
 static DT_ENTRY *disk;
-static unsigned long raid_base, raid_offset[MAX_RAID];
+static unsigned int raid_base, raid_offset[MAX_RAID];
 static char *raid_mbr[MAX_RAID];
 static int raid_device[MAX_RAID+1];
 static int raid_bios[MAX_RAID+1];
@@ -86,7 +87,7 @@ static int is_accessible(int device)
 }
 
 
-long raid_setup(void)
+int raid_setup(void)
 {
     int pass, mask;
     struct stat st;
@@ -98,7 +99,7 @@ long raid_setup(void)
     DEVICE dev;
     char *extrap;
     int raid_offset_set, all_pri_eq, pri_index;
-    long pri_offset;
+    int pri_offset;
     int raid_limit;
     
     if (!(boot=cfg_get_strg(cf_options,"boot"))) {
@@ -275,8 +276,8 @@ long raid_setup(void)
 	    disktab = disk;
 
 	    if (verbose >= 2 && do_md_install) {
-		printf("disk->start = %d\t\traid_offset = %ld (%08lX)\n",
-		   disk->start, (long)raid_offset[ndisk], (long)raid_offset[ndisk]);
+		printf("disk->start = %d\t\traid_offset = %d (%08X)\n",
+		   disk->start, (int)raid_offset[ndisk], (int)raid_offset[ndisk]);
 	    }
    	
 	/* derive the MBR name, which may be needed later */
@@ -453,7 +454,7 @@ long raid_setup(void)
 	
 	return raid_offset[pri_index];
     }	/* IF (test for a raid installation */
-}  /* long raid_setup(void) */
+}  /* int raid_setup(void) */
 
 
 
@@ -536,7 +537,7 @@ void raid_final(void)
 	    	index = lowest;
 	    }
 
-	    if (verbose>=2) printf("Specifed partition:  %s  raid offset = %08lX\n",
+	    if (verbose>=2) printf("Specifed partition:  %s  raid offset = %08X\n",
 					raid_list[pass], raid_offset[index]);
 
 	    if (!test)
@@ -592,11 +593,11 @@ void raid_final(void)
 
 /* form the mask of the raid bios codes and the list of offsets */
 /* this information goes into the MENUTABLE passed to the loader */
-int raid_mask(long *offsets)
+int raid_mask(int *offsets)
 {
     int mask = 0;
     int i, j;
-    long offset[MAX_BIOS_DEVICES];
+    int offset[MAX_BIOS_DEVICES];
     
     if (ndisk > MAX_RAID_DEVICES)
 	die("More than %d active RAID1 disks", MAX_RAID_DEVICES);
@@ -608,7 +609,7 @@ int raid_mask(long *offsets)
     }
     for (i=0; i<nelem(offset); i++) {
 	if ( (mask>>i) & 1 ) *offsets++ = offset[i];
-	if (do_md_install && verbose>=3) printf("RAID offset entry %ld  0x%08lX\n", offset[i], offset[i]);
+	if (do_md_install && verbose>=3) printf("RAID offset entry %d  0x%08X\n", offset[i], offset[i]);
     }
     
     if (verbose>=2) printf("RAID device mask 0x%04X\n", mask);
